# runtime.security

## Purpose
Domain runtime primitives for security.

## Owns
- Modules under `vyro.runtime.security`.

## Entry Points
- `vyro.runtime.security`

## Not Here
- Public app composition (`vyro.app`).
